git@vger.kernel.org mailing list mirror (one of many)
 help / color / mirror / code / Atom feed
From: Michael Haggerty <mhagger@alum.mit.edu>
To: Junio C Hamano <gitster@pobox.com>
Cc: "Nguyễn Thái Ngọc Duy" <pclouds@gmail.com>,
	"Stefan Beller" <sbeller@google.com>, "Jeff King" <peff@peff.net>,
	"Ævar Arnfjörð Bjarmason" <avarab@gmail.com>,
	"David Turner" <novalis@novalis.org>,
	"Brandon Williams" <bmwill@google.com>,
	git@vger.kernel.org, "Michael Haggerty" <mhagger@alum.mit.edu>
Subject: [PATCH v2 24/29] packed_refs_lock(): report errors via a `struct strbuf *err`
Date: Fri, 23 Jun 2017 09:01:42 +0200	[thread overview]
Message-ID: <2df54c75be6712588605ac5bb43f3e2845c6300c.1498200513.git.mhagger@alum.mit.edu> (raw)
In-Reply-To: <cover.1498200513.git.mhagger@alum.mit.edu>

That way the callers don't have to come up with error messages
themselves.

Signed-off-by: Michael Haggerty <mhagger@alum.mit.edu>
---
 refs/files-backend.c  |  6 ++----
 refs/packed-backend.c | 17 +++++++++++------
 refs/packed-backend.h |  6 +++---
 3 files changed, 16 insertions(+), 13 deletions(-)

diff --git a/refs/files-backend.c b/refs/files-backend.c
index 88de907148..8ea4e9ab05 100644
--- a/refs/files-backend.c
+++ b/refs/files-backend.c
@@ -1096,7 +1096,7 @@ static int files_pack_refs(struct ref_store *ref_store, unsigned int flags)
 	struct ref_to_prune *refs_to_prune = NULL;
 	struct strbuf err = STRBUF_INIT;
 
-	packed_refs_lock(refs->packed_ref_store, LOCK_DIE_ON_ERROR);
+	packed_refs_lock(refs->packed_ref_store, LOCK_DIE_ON_ERROR, &err);
 
 	iter = cache_ref_iterator_begin(get_loose_ref_cache(refs), NULL, 0);
 	while ((ok = ref_iterator_advance(iter)) == ITER_OK) {
@@ -2679,9 +2679,7 @@ static int files_initial_transaction_commit(struct ref_store *ref_store,
 		}
 	}
 
-	if (packed_refs_lock(refs->packed_ref_store, 0)) {
-		strbuf_addf(err, "unable to lock packed-refs file: %s",
-			    strerror(errno));
+	if (packed_refs_lock(refs->packed_ref_store, 0, err)) {
 		ret = TRANSACTION_GENERIC_ERROR;
 		goto cleanup;
 	}
diff --git a/refs/packed-backend.c b/refs/packed-backend.c
index cd214e07a1..78e877a9e3 100644
--- a/refs/packed-backend.c
+++ b/refs/packed-backend.c
@@ -515,7 +515,7 @@ static int write_packed_entry(FILE *fh, const char *refname,
 	return 0;
 }
 
-int packed_refs_lock(struct ref_store *ref_store, int flags)
+int packed_refs_lock(struct ref_store *ref_store, int flags, struct strbuf *err)
 {
 	struct packed_ref_store *refs =
 		packed_downcast(ref_store, REF_STORE_WRITE | REF_STORE_MAIN,
@@ -537,9 +537,15 @@ int packed_refs_lock(struct ref_store *ref_store, int flags)
 	if (hold_lock_file_for_update_timeout(
 			    &refs->lock,
 			    refs->path,
-			    flags, timeout_value) < 0 ||
-	    close_lock_file(&refs->lock))
+			    flags, timeout_value) < 0) {
+		unable_to_lock_message(refs->path, errno, err);
+		return -1;
+	}
+
+	if (close_lock_file(&refs->lock)) {
+		strbuf_addf(err, "unable to close %s: %s", refs->path, strerror(errno));
 		return -1;
+	}
 
 	/*
 	 * Now that we hold the `packed-refs` lock, make sure that our
@@ -698,10 +704,9 @@ int repack_without_refs(struct ref_store *ref_store,
 	if (!needs_repacking)
 		return 0; /* no refname exists in packed refs */
 
-	if (packed_refs_lock(&refs->base, 0)) {
-		unable_to_lock_message(refs->path, errno, err);
+	if (packed_refs_lock(&refs->base, 0, err))
 		return -1;
-	}
+
 	packed = get_packed_refs(refs);
 
 	/* Remove refnames from the cache */
diff --git a/refs/packed-backend.h b/refs/packed-backend.h
index dbc00d3396..210e3f35ce 100644
--- a/refs/packed-backend.h
+++ b/refs/packed-backend.h
@@ -6,10 +6,10 @@ struct ref_store *packed_ref_store_create(const char *path,
 
 /*
  * Lock the packed-refs file for writing. Flags is passed to
  * hold_lock_file_for_update(). Return 0 on success. On errors, set
  * errno appropriately and return a nonzero value.
  */
-int packed_refs_lock(struct ref_store *ref_store, int flags);
+int packed_refs_lock(struct ref_store *ref_store, int flags, struct strbuf *err);
 
 void add_packed_ref(struct ref_store *ref_store,
 		    const char *refname, const struct object_id *oid);
@@ -6,10 +6,10 @@ struct ref_store *packed_ref_store_create(const char *path,
 /*
  * Lock the packed-refs file for writing. Flags is passed to
- * hold_lock_file_for_update(). Return 0 on success. On errors, set
- * errno appropriately and return a nonzero value.
+ * hold_lock_file_for_update(). Return 0 on success. On errors, write
+ * an error message to `err` and return a nonzero value.
  */
-- 
2.11.0


  parent reply	other threads:[~2017-06-23  7:02 UTC|newest]

Thread overview: 52+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2017-06-23  7:01 [PATCH v2 00/29] Create a reference backend for packed refs Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 01/29] t1408: add a test of stale packed refs covered by loose refs Michael Haggerty
2017-06-23 18:59   ` Jeff King
2017-06-23 20:22     ` Junio C Hamano
2017-06-23  7:01 ` [PATCH v2 02/29] add_packed_ref(): teach function to overwrite existing refs Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 03/29] packed_ref_store: new struct Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 04/29] packed_ref_store: move `packed_refs_path` here Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 05/29] packed_ref_store: move `packed_refs_lock` member here Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 06/29] clear_packed_ref_cache(): take a `packed_ref_store *` parameter Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 07/29] validate_packed_ref_cache(): " Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 08/29] get_packed_ref_cache(): " Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 09/29] get_packed_refs(): " Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 10/29] add_packed_ref(): " Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 11/29] lock_packed_refs(): " Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 12/29] commit_packed_refs(): " Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 13/29] rollback_packed_refs(): " Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 14/29] get_packed_ref(): " Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 15/29] repack_without_refs(): " Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 16/29] packed_peel_ref(): new function, extracted from `files_peel_ref()` Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 17/29] packed_ref_store: support iteration Michael Haggerty
2017-06-23 19:12   ` Jeff King
2017-06-23  7:01 ` [PATCH v2 18/29] packed_read_raw_ref(): new function, replacing `resolve_packed_ref()` Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 19/29] packed-backend: new module for handling packed references Michael Haggerty
2017-06-23 19:35   ` Jeff King
2017-06-23 19:46     ` Stefan Beller
2017-06-23 21:20     ` Junio C Hamano
2017-06-23  7:01 ` [PATCH v2 20/29] packed_ref_store: make class into a subclass of `ref_store` Michael Haggerty
2017-06-23 19:40   ` Jeff King
2017-06-23  7:01 ` [PATCH v2 21/29] commit_packed_refs(): report errors rather than dying Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 22/29] commit_packed_refs(): use a staging file separate from the lockfile Michael Haggerty
2017-06-23 19:46   ` Jeff King
2017-06-24 11:43     ` Michael Haggerty
2017-06-24 11:57       ` Jeff King
2017-06-23  7:01 ` [PATCH v2 23/29] packed_refs_lock(): function renamed from lock_packed_refs() Michael Haggerty
2017-06-23  7:01 ` Michael Haggerty [this message]
2017-06-23  7:01 ` [PATCH v2 25/29] packed_refs_unlock(), packed_refs_is_locked(): new functions Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 26/29] clear_packed_ref_cache(): don't protest if the lock is held Michael Haggerty
2017-06-23 19:49   ` Jeff King
2017-06-23  7:01 ` [PATCH v2 27/29] commit_packed_refs(): remove call to `packed_refs_unlock()` Michael Haggerty
2017-06-23 19:51   ` Jeff King
2017-06-23  7:01 ` [PATCH v2 28/29] repack_without_refs(): don't lock or unlock the packed refs Michael Haggerty
2017-06-23 19:56   ` Jeff King
2017-07-01 17:11     ` Michael Haggerty
2017-06-23  7:01 ` [PATCH v2 29/29] read_packed_refs(): die if `packed-refs` contains bogus data Michael Haggerty
2017-06-23 19:58   ` Jeff King
2017-07-01 18:15     ` Michael Haggerty
2017-06-23 19:01 ` [PATCH v2 00/29] Create a reference backend for packed refs Jeff King
2017-06-23 20:00   ` Jeff King
2017-06-23 21:47     ` Junio C Hamano
2017-06-24  1:11       ` Jeff King
2017-06-24 11:14         ` Michael Haggerty
2017-06-23 20:24   ` Junio C Hamano

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: http://vger.kernel.org/majordomo-info.html

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=2df54c75be6712588605ac5bb43f3e2845c6300c.1498200513.git.mhagger@alum.mit.edu \
    --to=mhagger@alum.mit.edu \
    --cc=avarab@gmail.com \
    --cc=bmwill@google.com \
    --cc=git@vger.kernel.org \
    --cc=gitster@pobox.com \
    --cc=novalis@novalis.org \
    --cc=pclouds@gmail.com \
    --cc=peff@peff.net \
    --cc=sbeller@google.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://80x24.org/mirrors/git.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).